@@ -94,25 +94,25 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
                     filter="failed_keyword",
                     label="Failed Keywords",
                     description="Breaks on failed keywords",
+                    default=False,
+                ),
+                ExceptionBreakpointsFilter(
+                    filter="uncaughted_failed_keyword",
+                    label="Uncaughted Failed Keywords",
+                    description="Breaks on uncaughted failed keywords",
                     default=True,
-                    # supports_condition=True,
-                    # condition_description="expression",
                 ),
                 ExceptionBreakpointsFilter(
                     filter="failed_test",
                     label="Failed Test",
                     description="Breaks on failed tests",
                     default=False,
-                    # supports_condition=True,
-                    # condition_description="expression",
                 ),
                 ExceptionBreakpointsFilter(
                     filter="failed_suite",
                     label="Failed Suite",
                     description="Breaks on failed suite",
                     default=False,
-                    # supports_condition=True,
-                    # condition_description="expression",
                 ),
             ],
             supports_exception_options=True,
